@@ -19,19 +19,27 @@
 */
 
 #include "testfreebusyganttproxymodel.h"
+#include "freebusyganttproxymodel.h"
 #include "modeltest.h"
-#include "CalendarSupport/FreeBusyItem"
-#include "CalendarSupport/FreeBusyItemModel"
-#include "../src/freebusyganttproxymodel.h"
+
+#include <CalendarSupport/FreeBusyItem>
+#include <CalendarSupport/FreeBusyItemModel>
 
 #include <KGantt/KGanttGraphicsView>
 #include <KCalCore/Attendee>
 
-#include <qtest.h>
-
+#include <QTest>
+#include <QStandardPaths>
 QTEST_MAIN(FreeBusyGanttProxyModelTest)
+
 using namespace IncidenceEditorNG;
 
+void FreeBusyGanttProxyModelTest::initTestCase()
+{
+    qputenv("TZ", "UTC");
+    QStandardPaths::setTestModeEnabled(true);
+}
+
 void FreeBusyGanttProxyModelTest::testModelValidity()
 {
     CalendarSupport::FreeBusyItemModel *fbModel = new CalendarSupport::FreeBusyItemModel();
@@ -43,8 +51,8 @@ void FreeBusyGanttProxyModelTest::testModelValidity()
 
     QVERIFY(ganttModel->rowCount() == 0);
 
-    const KDateTime dt1(QDate(2010, 8, 24), QTime(7, 0, 0), KDateTime::UTC);
-    const KDateTime dt2(QDate(2010, 8, 24), QTime(16, 0, 0), KDateTime::UTC);
+    const QDateTime dt1(QDate(2010, 8, 24), QTime(7, 0, 0), Qt::UTC);
+    const QDateTime dt2(QDate(2010, 8, 24), QTime(16, 0, 0), Qt::UTC);
     KCalCore::Attendee::Ptr a1(new KCalCore::Attendee(QStringLiteral("fred"), QStringLiteral("fred@example.com")));
     KCalCore::FreeBusy::Ptr fb1(new KCalCore::FreeBusy());
 
@@ -54,8 +62,8 @@ void FreeBusyGanttProxyModelTest::testModelValidity()
     CalendarSupport::FreeBusyItem::Ptr item1(new CalendarSupport::FreeBusyItem(a1, nullptr));
     item1->setFreeBusy(fb1);
 
-    const KDateTime dt3(QDate(2010, 8, 25), QTime(7, 0, 0), KDateTime::UTC);
-    const KDateTime dt4(QDate(2010, 8, 25), QTime(16, 0, 0), KDateTime::UTC);
+    const QDateTime dt3(QDate(2010, 8, 25), QTime(7, 0, 0), Qt::UTC);
+    const QDateTime dt4(QDate(2010, 8, 25), QTime(16, 0, 0), Qt::UTC);
     KCalCore::Attendee::Ptr a2(new KCalCore::Attendee(QStringLiteral("joe"), QStringLiteral("joe@example.com")));
     KCalCore::FreeBusy::Ptr fb2(new KCalCore::FreeBusy());
 
@@ -85,16 +93,15 @@ void FreeBusyGanttProxyModelTest::testModelValidity()
     QCOMPARE(parent1.data(), source_parent1.data());
     QCOMPARE(parent1.data(KGantt::ItemTypeRole).toInt(), (int) KGantt::TypeMulti);
 
-
     QModelIndex child0_0 = ganttModel->index(0, 0, parent0);
     QModelIndex child0_1 = ganttModel->index(1, 0, parent0);
     QVERIFY(child0_0.isValid());
     QVERIFY(child0_1.isValid());
 
     QCOMPARE(child0_0.data(KGantt::ItemTypeRole).toInt(), (int) KGantt::TypeTask);
-    QCOMPARE(child0_0.data(KGantt::StartTimeRole).value<QDateTime>(), dt1.dateTime());
+    QCOMPARE(child0_0.data(KGantt::StartTimeRole).toDateTime(), dt1);
     QCOMPARE(child0_1.data(KGantt::ItemTypeRole).toInt(), (int) KGantt::TypeTask);
-    QCOMPARE(child0_1.data(KGantt::StartTimeRole).value<QDateTime>(), dt2.dateTime());
+    QCOMPARE(child0_1.data(KGantt::StartTimeRole).toDateTime(), dt2);
 
     QModelIndex child1_0 = ganttModel->index(0, 0, parent1);
     QModelIndex child1_1 = ganttModel->index(1, 0, parent1);
@@ -102,9 +109,7 @@ void FreeBusyGanttProxyModelTest::testModelValidity()
     QVERIFY(child1_1.isValid());
 
     QCOMPARE(child1_0.data(KGantt::ItemTypeRole).toInt(), (int) KGantt::TypeTask);
-    QCOMPARE(child1_0.data(KGantt::StartTimeRole).value<QDateTime>(), dt3.dateTime());
+    QCOMPARE(child1_0.data(KGantt::StartTimeRole).toDateTime(), dt3);
     QCOMPARE(child1_1.data(KGantt::ItemTypeRole).toInt(), (int) KGantt::TypeTask);
-    QCOMPARE(child1_1.data(KGantt::StartTimeRole).value<QDateTime>(), dt4.dateTime());
-
+    QCOMPARE(child1_1.data(KGantt::StartTimeRole).toDateTime(), dt4);
 }
-
