@@ -129,11 +129,11 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
     connect(mUi->mSolveButton, &QPushButton::clicked, this,
             &IncidenceAttendee::slotSolveConflictPressed);
     /* Added as part of kolab/issue2297, which is currently under review
-    connect(mUi->mOrganizerCombo, static_cast<void (KComboBox::*)(const QString &)>(&KComboBox::activated), this, &IncidenceAttendee::slotOrganizerChanged);
+    connect(mUi->mOrganizerCombo, QOverload<const QString &>::of(&KComboBox::activated),
+            this, &IncidenceAttendee::slotOrganizerChanged);
     */
-    connect(mUi->mOrganizerCombo,
-            static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this,
-            &IncidenceAttendee::checkDirtyStatus);
+    connect(mUi->mOrganizerCombo, QOverload<int>::of(&KComboBox::currentIndexChanged),
+            this, &IncidenceAttendee::checkDirtyStatus);
 
     connect(mDateTime, &IncidenceDateTime::startDateChanged, this,
             &IncidenceAttendee::slotEventDurationChanged);
@@ -422,7 +422,7 @@ void IncidenceAttendee::groupSearchResult(KJob *job)
 
 void IncidenceAttendee::updateGroupExpand()
 {
-    mUi->mGroupSubstitution->setEnabled(mGroupList.count() > 0);
+    mUi->mGroupSubstitution->setEnabled(!mGroupList.isEmpty());
 }
 
 void IncidenceAttendee::slotGroupSubstitutionPressed()
@@ -477,7 +477,7 @@ void IncidenceAttendee::slotSelectAddresses()
 
     QWeakPointer<Akonadi::EmailAddressSelectionDialog> dialog(d);
     dialog.data()->view()->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
-
+    dialog.data()->setWindowTitle(i18n("Select Attendees"));
     if (dialog.data()->exec() == QDialog::Accepted) {
         Akonadi::EmailAddressSelectionDialog *dialogPtr = dialog.data();
         if (dialogPtr) {
@@ -532,8 +532,7 @@ void IncidenceEditorNG::IncidenceAttendee::slotSolveConflictPressed()
                                                                  mDateTime->startTime(),
                                                                  duration, mConflictResolver,
                                                                  mParentWidget));
-    dialog->slotUpdateIncidenceStartEnd(mDateTime->currentStartDateTime(),
-                                        mDateTime->currentEndDateTime());
+    dialog->slotUpdateIncidenceStartEnd(mDateTime->currentStartDateTime(), mDateTime->currentEndDateTime());
     if (dialog->exec() == QDialog::Accepted) {
         qCDebug(INCIDENCEEDITOR_LOG) << dialog->selectedStartDate() << dialog->selectedStartTime();
         if (dialog->selectedStartDate().isValid() && dialog->selectedStartTime().isValid()) {
@@ -546,8 +545,8 @@ void IncidenceEditorNG::IncidenceAttendee::slotSolveConflictPressed()
 void IncidenceAttendee::slotConflictResolverAttendeeChanged(const QModelIndex &topLeft,
                                                             const QModelIndex &bottomRight)
 {
-    if (AttendeeTableModel::FullName <= bottomRight.column()
-        && AttendeeTableModel::FullName >= topLeft.column()) {
+    if (AttendeeTableModel::FullName <= bottomRight.column() &&
+        AttendeeTableModel::FullName >= topLeft.column()) {
         for (int i = topLeft.row(); i <= bottomRight.row(); ++i) {
             QModelIndex email = dataModel()->index(i, AttendeeTableModel::Email);
             KCalCore::Attendee::Ptr attendee = dataModel()->data(email,
@@ -613,12 +612,10 @@ void IncidenceAttendee::slotFreeBusyAdded(const QModelIndex &parent, int first,
     QAbstractItemModel *model = mConflictResolver->model();
     for (int i = first; i <= last; ++i) {
         QModelIndex index = model->index(i, 0, parent);
-        const KCalCore::Attendee::Ptr &attendee = model->data(index,
-                                                              CalendarSupport::FreeBusyItemModel::AttendeeRole)
-                                                  .value<KCalCore::Attendee::Ptr>();
-        const KCalCore::FreeBusy::Ptr &fb = model->data(index,
-                                                        CalendarSupport::FreeBusyItemModel::FreeBusyRole)
-                                            .value<KCalCore::FreeBusy::Ptr>();
+        const KCalCore::Attendee::Ptr &attendee =
+            model->data(index, CalendarSupport::FreeBusyItemModel::AttendeeRole).value<KCalCore::Attendee::Ptr>();
+        const KCalCore::FreeBusy::Ptr &fb =
+            model->data(index, CalendarSupport::FreeBusyItemModel::FreeBusyRole).value<KCalCore::FreeBusy::Ptr>();
         if (attendee) {
             updateFBStatus(attendee, fb);
         }
@@ -635,12 +632,10 @@ void IncidenceAttendee::slotFreeBusyChanged(const QModelIndex &topLeft,
     QAbstractItemModel *model = mConflictResolver->model();
     for (int i = topLeft.row(); i <= bottomRight.row(); ++i) {
         QModelIndex index = model->index(i, 0);
-        const KCalCore::Attendee::Ptr &attendee = model->data(index,
-                                                              CalendarSupport::FreeBusyItemModel::AttendeeRole)
-                                                  .value<KCalCore::Attendee::Ptr>();
-        const KCalCore::FreeBusy::Ptr &fb = model->data(index,
-                                                        CalendarSupport::FreeBusyItemModel::FreeBusyRole)
-                                            .value<KCalCore::FreeBusy::Ptr>();
+        const KCalCore::Attendee::Ptr &attendee =
+            model->data(index, CalendarSupport::FreeBusyItemModel::AttendeeRole).value<KCalCore::Attendee::Ptr>();
+        const KCalCore::FreeBusy::Ptr &fb =
+            model->data(index, CalendarSupport::FreeBusyItemModel::FreeBusyRole).value<KCalCore::FreeBusy::Ptr>();
         if (attendee) {
             updateFBStatus(attendee, fb);
         }
@@ -652,12 +647,10 @@ void IncidenceAttendee::updateFBStatus()
     QAbstractItemModel *model = mConflictResolver->model();
     for (int i = 0; i < model->rowCount(); ++i) {
         QModelIndex index = model->index(i, 0);
-        const KCalCore::Attendee::Ptr &attendee = model->data(index,
-                                                              CalendarSupport::FreeBusyItemModel::AttendeeRole)
-                                                  .value<KCalCore::Attendee::Ptr>();
-        const KCalCore::FreeBusy::Ptr &fb = model->data(index,
-                                                        CalendarSupport::FreeBusyItemModel::FreeBusyRole)
-                                            .value<KCalCore::FreeBusy::Ptr>();
+        const KCalCore::Attendee::Ptr &attendee =
+            model->data(index, CalendarSupport::FreeBusyItemModel::AttendeeRole).value<KCalCore::Attendee::Ptr>();
+        const KCalCore::FreeBusy::Ptr &fb =
+            model->data(index, CalendarSupport::FreeBusyItemModel::FreeBusyRole).value<KCalCore::FreeBusy::Ptr>();
         if (attendee) {
             updateFBStatus(attendee, fb);
         }
@@ -668,19 +661,18 @@ void IncidenceAttendee::updateFBStatus(const KCalCore::Attendee::Ptr &attendee,
                                        const KCalCore::FreeBusy::Ptr &fb)
 {
     KCalCore::Attendee::List attendees = mDataModel->attendees();
-    KDateTime startTime = mDateTime->currentStartDateTime();
-    KDateTime endTime = mDateTime->currentEndDateTime();
+    QDateTime startTime = mDateTime->currentStartDateTime();
+    QDateTime endTime = mDateTime->currentEndDateTime();
     if (attendees.contains(attendee)) {
         int row = dataModel()->attendees().indexOf(attendee);
         QModelIndex attendeeIndex = dataModel()->index(row, AttendeeTableModel::Available);
         if (fb) {
             KCalCore::Period::List busyPeriods = fb->busyPeriods();
-            for (KCalCore::Period::List::Iterator it = busyPeriods.begin(); it != busyPeriods.end();
-                 ++it) {
+            for (auto it = busyPeriods.begin(); it != busyPeriods.end(); ++it) {
                 // periods started before and laping into the incidence (s < startTime && e >= startTime)
                 // periods starting in the time of incidende (s >= startTime && s <= endTime)
-                if (((*it).start() < startTime && (*it).end() > startTime)
-                    || ((*it).start() >= startTime && (*it).start() <= endTime)) {
+                if (((*it).start() < startTime && (*it).end() > startTime) ||
+                    ((*it).start() >= startTime && (*it).start() <= endTime)) {
                     switch (attendee->status()) {
                     case KCalCore::Attendee::Accepted:
                         dataModel()->setData(attendeeIndex, AttendeeTableModel::Accepted);
@@ -693,7 +685,7 @@ void IncidenceAttendee::updateFBStatus(const KCalCore::Attendee::Ptr &attendee,
             }
             dataModel()->setData(attendeeIndex, AttendeeTableModel::Free);
         } else {
-            dataModel()->setData(attendeeIndex, AttendeeTableModel::Unkown);
+            dataModel()->setData(attendeeIndex, AttendeeTableModel::Unknown);
         }
     }
 }
@@ -720,8 +712,8 @@ void IncidenceAttendee::slotUpdateConflictLabel(int count)
 void IncidenceAttendee::slotGroupSubstitutionAttendeeChanged(const QModelIndex &topLeft,
                                                              const QModelIndex &bottomRight)
 {
-    if (AttendeeTableModel::FullName <= bottomRight.column()
-        && AttendeeTableModel::FullName >= topLeft.column()) {
+    if (AttendeeTableModel::FullName <= bottomRight.column() &&
+        AttendeeTableModel::FullName >= topLeft.column()) {
         for (int i = topLeft.row(); i <= bottomRight.row(); ++i) {
             QModelIndex email = dataModel()->index(i, AttendeeTableModel::Email);
             KCalCore::Attendee::Ptr attendee = dataModel()->data(email,
@@ -820,10 +812,10 @@ bool IncidenceAttendee::iAmOrganizer() const
 
 void IncidenceAttendee::insertAttendeeFromAddressee(const KContacts::Addressee &a, int pos /*=-1*/)
 {
-    const bool sameAsOrganizer = mUi->mOrganizerCombo
-                                 && KEmailAddress::compareEmail(a.preferredEmail(),
-                                                                mUi->mOrganizerCombo->currentText(),
-                                                                false);
+    const bool sameAsOrganizer =
+        mUi->mOrganizerCombo && KEmailAddress::compareEmail(a.preferredEmail(),
+                                                            mUi->mOrganizerCombo->currentText(),
+                                                            false);
     KCalCore::Attendee::PartStat partStat = KCalCore::Attendee::NeedsAction;
     bool rsvp = true;
 
@@ -845,8 +837,8 @@ void IncidenceAttendee::insertAttendeeFromAddressee(const KContacts::Addressee &
 
 void IncidenceAttendee::slotEventDurationChanged()
 {
-    const KDateTime start = mDateTime->currentStartDateTime();
-    const KDateTime end = mDateTime->currentEndDateTime();
+    const QDateTime start = mDateTime->currentStartDateTime();
+    const QDateTime end = mDateTime->currentEndDateTime();
 
     if (start >= end) {   // This can happen, especially for todos.
         return;
